## v0.2.0 (2024-12-25)

### Feat

- add usage section in README

## v0.1.0 (2024-12-25)

### Feat

- **client**: add first client implementation
- **config**: first config version
- **tests**: add test for clients
- **tests**: add test server
- add pyproject.toml
